@@ -1,2 +1,2 @@
-from ._private._data_types import KafkaServer, KafkaTopic
+from ._private._data_types import KafkaTopic
 from ._private._pipeline_elements import KafkaProducer, KafkaConsumer, KafkaTriggererConsumer
