@@ -1,10 +1,11 @@
-import threading
+import time
 
-from ... import EventSource, EventSink, Event, TriggerableEventBatchSource, TriggererEventSource
-from ..._private._utilities import *
-from ._data_types import *
 from kafka import KafkaConsumer as KC, KafkaProducer as KP
 
+from ._data_types import *
+from ... import EventSink, Event, TriggerableEventBatchSource, TriggererEventSource
+from ..._private._utilities import *
+
 
 class KafkaTriggererConsumer(TriggererEventSource):
     def __init__(self,
@@ -59,6 +60,7 @@ class KafkaConsumer(TriggerableEventBatchSource):
                  offset_reset_strategy: str = 'latest',
                  max_records: int = None,
                  timeout_ms: int = 0,
+                 empty_check_timeout_ms: int = 5000,
                  **kwargs):
         super().__init__(**kwargs)
         self.topic = topic
@@ -66,7 +68,9 @@ class KafkaConsumer(TriggerableEventBatchSource):
         self.deserializer = deserializer
         self.offset_reset_strategy = offset_reset_strategy
         self.max_records = max_records
-        self.timeout_ms: int = timeout_ms
+        self.timeout_ms = timeout_ms
+        self.empty_check_timeout_s = empty_check_timeout_ms / 1000
+        self.last_empty_epoch: float = 0
         self.inner_consumer: KC = KC(
             self.topic.topic_id,
             bootstrap_servers=[str(self.topic.server)],
@@ -77,6 +81,8 @@ class KafkaConsumer(TriggerableEventBatchSource):
         )
 
     def get_event_batch(self) -> List[Event]:
+        if time.time() < self.last_empty_epoch + self.empty_check_timeout_s:
+            return []
         records: Dict = \
             self.inner_consumer.poll(timeout_ms=self.timeout_ms, max_records=self.max_records) \
                 if self.max_records is not None \
@@ -89,6 +95,8 @@ class KafkaConsumer(TriggerableEventBatchSource):
                     print(f'Invalid kafka message with type {str(type(event))}')  # TODO log
                 else:
                     record_list.append(event)
+        if len(record_list) == 0:
+            self.last_empty_epoch = time.time()
         return record_list
 
 
@@ -96,13 +104,16 @@ class KafkaProducer(EventSink):
     def __init__(self,
                  topic: KafkaTopic,
                  serializer: Callable[[Any], str],
+                 producer_config: ProducerConfig,
                  **kwargs):
         super().__init__(**kwargs)
         self.topic = topic
         self.serializer = serializer
 
+        producer_config = producer_config if producer_config is not None else ProducerConfig()
         self.inner_producer: KP = KP(bootstrap_servers=[str(self.topic.server)],
-                                     value_serializer=lambda x: self.serializer(x).encode('utf-8'))
+                                     value_serializer=lambda x: self.serializer(x).encode('utf-8'),
+                                     **producer_config.producer_kwargs)
 
     def drown_event(self, event: Event) -> None:
         self.inner_producer.send(self.topic.topic_id, value=event)
